# Credits

JupySQL would not be possible without the extraordinary work of Catherine Devlin, the original author of `ipython-sql`, which JupySQL is a fork of. Here is the list of other individuals that contributed to `ipython-sql` (taken from the original repository):

- Matthias Bussonnier for help with configuration
- Olivier Le Thanh Duong for ``%config`` fixes and improvements
- Distribute_
- Buildout_
- modern-package-template_
- Mike Wilson for bind variable code
- Thomas Kluyver and Steve Holden for debugging help
- Berton Earnshaw for DSN connection syntax
- Bruno Harbulot for DSN example 
- Andrés Celis for SQL Server bugfix
- Michael Erasmus for DataFrame truth bugfix
- Noam Finkelstein for README clarification
- Xiaochuan Yu for `<<` operator, syntax colorization
- Amjith Ramanujam for PGSpecial and incorporating it here
- Alexander Maznev for better arg parsing, connections accepting specified creator
- Jonathan Larkin for configurable displaycon 
- Jared Moore for ``connection-arguments`` support
- Gilbert Brault for ``--append`` 
- Lucas Zeer for multi-line bugfixes for var substitution, ``<<`` 
- vkk800 for ``--file``
- Jens Albrecht for MySQL DatabaseError bugfix
- meihkv for connection-closing bugfix
